#
# spec file for package python-django-crispy-forms
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
# Multibuild: break cycles with crispy-bootstrap{3,4,5}
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define mod_name django_crispy_forms
%{?sle15_python_module_pythons}
Name:           python-django-crispy-forms%{psuffix}
Version:        2.4
Release:        1.1
Summary:        Django DRY Forms
License:        MIT
URL:            https://github.com/maraujop/django-crispy-forms
Source:         https://files.pythonhosted.org/packages/source/d/%{mod_name}/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Django >= 4.2}
BuildRequires:  %{python_module crispy-bootstrap3}
BuildRequires:  %{python_module crispy-bootstrap4}
BuildRequires:  %{python_module crispy-bootstrap5}
BuildRequires:  %{python_module django-crispy-forms = %{version}}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-Django >= 4.2
Recommends:     python-crispy-bootstrap3
Recommends:     python-crispy-bootstrap4
Recommends:     python-crispy-bootstrap5
BuildArch:      noarch
%python_subpackages

%description
A module to build programmatic reusable layouts out of components
with control over the rendered HTML without writing HTML in
templates, and without breaking the standard way of doing things in
Django.

%prep
%setup -q -n %{mod_name}-%{version}

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
export DJANGO_SETTINGS_MODULE=tests.test_settings
export PYTHONPATH=${PWD}
%pytest -rs tests/
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc CONTRIBUTORS.txt README.rst
%{python_sitelib}/*crispy[-_]forms*/
%endif

%changelog
* Tue Apr 15 2025 Dirk Müller <dmueller@suse.com>
- update to 2.4:
  * ## 2.4 (2025-04-13)
  * Added support for Python 3.13.
  * Confirmed support for Django 5.2.
* Tue Nov  5 2024 Markéta Machová <mmachova@suse.com>
- update to 2.3
  * Added support for Django 5.1.
  * Allowed pass through of context when rendering a Fieldset layout object.
  * Fixed unexpected addition the 'active' css_class to AccordionGroup
* Tue Feb  6 2024 Christian Keil <keil@dfn-cert.de>
- Switch to Python 3.11 build.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1:
  * Added support for Django 5.0.
  * Dropped support for Django 3.2, 4.0 and 4.1.
  * Added support for Python 3.12.
  * Dropped support for Python 3.7.
  * See the 2.1 Milestone for the full change
* Tue Jun 13 2023 Markéta Machová <mmachova@suse.com>
- Update to v2.0
  * Removed all Bootstrap template packs. These template packs are now available as standalone packages.
    To upgrade, install the required template pack and add it to your INSTALLED_APPS setting.
  * See python-crispy-bootstrap3, python-crispy-bootstrap4 and python-crispy-bootstrap5
  * Removed uni-form template pack. Uni-Form specific classes previously added to every template pack
    e.g. textInput are now removed.
  * The form_style attribute of FormHelper is removed.
  * The form_style positional argument to render_field() is removed.
  * The form_style positional argument to the render() method of all LayoutObjects is removed.
  * Widespread use of the |safe in crispy-form templates is removed. Audit for html input in your forms
    especially for Field and Prepended/Appended text. To retain the previous behaviour mark text as safe
    in your project code using mark_safe().
  * Dropped support for Django 2.2.
  * Added support for Django 4.1 and 4.2.
  * Added support for Python 3.11.
  * More changes, see https://github.com/django-crispy-forms/django-crispy-forms/releases
- Convert to multibuild because of the template packs
* Thu Aug 25 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.14.0
  * Added support for Python 3.10
  * Dropped support for Django 3.1
  * Dropped support for Python 3.6
  * Added bootstrap modal layout object
  * Added input_size argument to FieldWithButtons to allow customisation
    of the size of the input in the Bootstrap 4 template pack
* Sun Jan  9 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.13.0
  * Added support for Django 4.0
- from v1.12.0
  * Fixed rendering of grouped checkboxes and radio inputs in the
    Bootstrap 4 template pack.
  * Introduced new input_size argument to AppendedText,
    PrependedText and PrependedAppendedText. This allows the size
    of these grouped inputs to be changed in the Bootstrap 4
    template pack
  * Confirmed support for Django 3.2
  * Dropped support for Python 3.5
  * Dropped support for Django 3.0
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- Update to 1.11.2
  * Fixed test causing SystemCheckError in some cases.
  * Radio and Checkbox now respect the field's disabled attribute when using the
    Bootstrap4 template pack.
  * Implemeneted custom-select for Select widgets in the Bootstrap4 Template Pack
  * Added custom-select for select widgets within prepended and appended fields
* Sat Sep  5 2020 Matthias Fehring <buschmann23@opensuse.org>
- Update to 1.9.2
  * Fixed FileField UI bug
- Remove test suite from runtime installation
- Fix test suite execution
* Tue Jun  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 1.9.1
  * Added Bootstrap 4 styling for clearable file widget.
  * Fixed FileField UI bug
  * Project now uses GitHub actions for testing
* Mon Mar  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.0:
  * Removed support for Python 2.
  * Removed support for Django versions prior to 2.2.
  * CSS for Column layout object in Bootstrap 4 template pack changed to 'col-md'.
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.1:
  * Fixing FileField UI bug introduced with 1.8.0
  * Remove is-valid css class for radio (bug introduced with 1.8.0)
  * Various alignment and margin fixes for Bootstrap 4 template pack
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.0:
  * Update to support new django releases
  * Numerous improvements to bootstrap4 template pack
- Remove patches:
  * django-21.patch
  * django-20.patch
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Test only with pytest 3, newer releases not compatible
* Fri May 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix old leap build
* Wed Aug  8 2018 tchvatal@suse.com
- Add patches to work with django 2.0 and 2.1 properly:
  * django-20.patch
  * django-21.patch
* Wed Aug  8 2018 jengelh@inai.de
- Trim marketing from description.
* Wed Aug  1 2018 tchvatal@suse.com
- Version update to 1.7.2:
  * Bootstrap4 fixes
  * Small bugfixes around
* Wed Nov 15 2017 buschmann23@opensuse.org
- spec file
  * require python-Django instead of python-django
* Wed Nov 15 2017 buschmann23@opensuse.org
- spec file
  * convert to single spec file
* Tue Oct 24 2017 buschmann23@opensuse.org
- Update to version 1.7.0
  * Fixes compatibility with Django 2.0
  * Various other fixes.
* Mon Feb  6 2017 sbrabec@suse.com
- Update to version 1.6.1.
  * Updates compatibility for Django 1.10
  * A number of small Bootstrap 4 fixes.
  * Dropped support for Django 1.7
  * Added Bootstrap 4 template pack
  * Other small fixes.
* Mon Nov  9 2015 mcihar@suse.cz
- Update to version 1.5.2
  * Fix: KeyError: u'wrapper_class' when clearing template context. #511, #512
  * Fix: Alignment of stacked checkboxes and radio buttons in Bootstrap 3 #358
  * Switched to py.test. Modernised test suite. Enabled tox, code coverage and Travis for all
  supported Python/Django versions. [See list of Merged "Testing/Process" PRs here](https://github.com/maraujop/django-crispy-forms/pulls?q=is%%3Apr+is%%3Amerged+milestone%%3A1.5.1+label%%3ATesting%%2FProcess)
  * Added compatibility with Python 3.2
  * Fix: Allow LayoutObject & BaseInputs to accept custom template #493
  * Fixed compatibility with: Python 3, Django 1.7, Django 1.8 and Django 1.4.16. Merged PR #417, but thanks to PRs #369, #368 and #310. Closes also #383.
  * Updated test suite for compatibility with all supported Django versions 1.4, 1.7, 1.8 and run CI against these and Django `master`. See #451, #455.
  * Bug fix for specifying `template_pack` in `{%% crispy %%}` tag, `bootstrap3` couldn't be set that way.
  * New doc section for creating custom template packs.
  * Fixed Bootstrap3 checkbox alignment issues with label texts, see #275.
  * First `AccordionGroup` can now be set to `active=False`, see #246.
  * Fixed Bootstrap3 checkbox alignment issues for all device sizes, see #225 and #267.
  * All forms are now rendered with {{ form.media }}, this makes forms containing widgets with `Media` meta class work, see #263.
  * Adjusted `{%% specialspaceless %%}` to avoid breaking intended spaces and be less aggressive, see #250.
  * Fixed inputs rendering for bootstrap3 and redo `FormActions` layout object bootstrap3 template for correct alignment, see #279.
  * `MultiField` now obeys `form_show_labels`, see #278.
  * Added `wrapper_class` to `bootstrap.InlineRadios`, see #272.
  * Render label for checkboxes within `table_inline_formset.html`, see #262.
  * Removed deprecated layout object `AppendedPrependedText`, replaced by `PrependedAppendedText`.
  * Fixed `PrependedAppendedText` when rendering a select widget, in bootstrap and bootstrap3 template packs, see #258.
  * Added support to `{%% crispy_addon %%}` tag for `form_show_labels`, see #256.
  * Major cleanup and refactor of the template pack system thanks to @tepez, see #217 and #237:
  - Template packs are now self contained/independent, removing dangerous cross references. If you have a custom template pack this can cause backwards incompatibility, but it will pay in the future to adjust to this changes.
  - `MultiField` cannot be used with `bootstrap` or `bootstrap3` template packs.
  - Added `template_pack` `FormHelper` attribute, so that template packs can be specified at form helper level. This changes layout objects `render` behavior.
  * Default template pack is now `bootstrap3`.
  * Make `CRISPY_TEMPLATE_PACK` setting optional, see #237 and #244.
- Run testsuite in %%check
- Remove no longer needed cleanups on source tarballs, added removal of .pyc files
- Spec file cleanup
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 1.4.0
  + Bootstrap 3 inline forms support and docs for inline forms with
    Bootstrap 3, see #233.
  + update_attributes can now work with a field name, see docs.
  + Adjusted unicode checkings for Python 3, see #231.
    Adjusted how bootstrap Tab layout object attributes are applied to
    make sense, see #228.
  + Major refactor of testing suite architecture, breaking huge tests.py
    file into several and also splitting tests for different template packs
    into different tests cases, runners for template packs updated.
  + Added support for horizontal forms in bootstrap3, see #209.
  + Fixed spaces missing when rendering several submit inputs continued, see #211.
  + Fixed checkboxes and radios for Bootstrap3, adjusted multiple inline
    radios and checkboxes, see #225.
  + Update accordion markup for bootstrap3 compatibilty, see #229.
  + Moved UneditableField to bootstrap module, place where it should live,
    no backwards compatible import left behind.
  + Added bootstrap3 template pack thanks to James Friedman, see #213 and #209.
  + RadioSelect and CheckboxSelectMultiple widget values and texts were being
    localized, when they shouldn't bee, see #214.
  + If Django widget attrs where set for RadioSelect or CheckboxSelectMultiple
    they were not being rendered by crispy-forms, see #206.
  + form_show_labels wasn't working correctly with some layout objects, see #193
- Do not build documentation; there is not available anymore
- Remove redundant files with fdupes
* Tue May  1 2012 jfunk@funktronics.ca
- Update to 1.1.3
  * |crispy and |as_crispy_field filters were not rendering errors. Thanks to
    @ximi for reporting it and submitting a patch. See issue #GH-28
  * Fixing a test that was breaking when language was not English. Thanks to
    @gaftech, see #GH-30
  * Fixing radioselect.html and checkboxselectmultiple.html templates. Thanks
    to Christopher Petrilli for submitting a patch for radioselect. See issue
    [#]GH-35
  * HTML attributes can now be set in BaseInput subclasses like Button by
    @jamesmfriedman. See #GH-32
  * Fix for dynamic crispy-forms with Meta classes by Jeroen Vloothuis. See
    [#]GH-37
  * Labels now use id_for_label instead of auto_id to avoid ids breaking on
    multiwidgets. by Daniel Izquierdo. See #GH-38
  * Adding a flatatt custom function in utils.py for flatting extra HTML
    attributes.
  * HTML attributes can now be set in Div layout object.
  * Adding tests for new functionality and bugs.
- 1.1.2 (2012/2/29)
  * input name attribute is no longer slugified if only one word is provided,
    respecting caps.
  * Changes in bootstrap global error templates by David Bennett.
  * Added class control-label to labels, for horizontal layout thanks to
    bitrut.
  * Using {{ field.html_name }} instead of {{ field.name }} in field
    templates, so that they work with form prefixes (formwizard) by Patrick
    Toal.
  * Fixing error rendering in bootstrap AppendedText and PrependedText.
  * Applying field.css_classes in bootstrap field.html instead of widget
    classes.
  * Fixes for bootstrap simple checkbox input to be wrapped correctly.
- 1.1.1 (2012/2/17)
  * Fixing a critical bug in bootstrap templates, that was breaking
    {%% load crispy_forms_tags %%}
* Fri Nov 25 2011 jfunk@funktronics.ca
- Initial release
